.. image:: https://img.shields.io/pypi/v/vr.runners.svg
   :target: https://pypi.org/project/vr.runners

.. image:: https://img.shields.io/pypi/pyversions/vr.runners.svg

.. image:: https://img.shields.io/travis/yougov/vr.runners/master.svg
   :target: https://travis-ci.org/yougov/vr.runners

.. .. image:: https://img.shields.io/appveyor/ci/jaraco/skeleton/master.svg
..    :target: https://ci.appveyor.com/project/jaraco/skeleton/branch/master

.. .. image:: https://readthedocs.org/projects/skeleton/badge/?version=latest
..    :target: https://skeleton.readthedocs.io/en/latest/?badge=latest

``vr.runners`` is a component of the `Velociraptor
<https://github.com/yougov/velociraptor>`_ project.

Runners are used for configuring, invoking, and tearing down
lxc containers.
